==> calligra_2.8.90.orig.tar.xz: calligra-2.8.90/krita/plugins/extensions/resourcemanager/dlg_bundle_manager.h <==
/*
 *  Copyright (c) 2014 Victor Lafon metabolic.ewilan@hotmail.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef DLG_BUNDLE_MANAGER_H
#define DLG_BUNDLE_MANAGER_H

#include <QWidget>

#include <kdialog.h>

class ResourceBundle;
class QListWidget;
class QListWidgetItem;

namespace Ui
{
class WdgDlgBundleManager;
}

class DlgBundleManager : public KDialog
{
    Q_OBJECT
public:
    explicit DlgBundleManager(QWidget *parent = 0);

private slots:

    void accept();
    void addSelected();
    void removeSelected();
    void itemSelected(QListWidgetItem *current, QListWidgetItem *previous);
    void itemSelected(QListWidgetItem *current);
    void editBundle();

private:

    QWidget *m_page;
    Ui::WdgDlgBundleManager *m_ui;

    void fillListWidget(QList<ResourceBundle*> bundles, QListWidget *w);

    QMap<QString, ResourceBundle*> m_blacklistedBundles;
    QMap<QString, ResourceBundle*> m_activeBundles;

    ResourceBundle *m_currentBundle;
};

#endif // DLG_BUNDLE_MANAGER_H

==> calligra-2.9.0.tar.xz: calligra-2.9.0/krita/plugins/extensions/resourcemanager/dlg_bundle_manager.h <==
/*
 *  Copyright (c) 2014 Victor Lafon metabolic.ewilan@hotmail.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef DLG_BUNDLE_MANAGER_H
#define DLG_BUNDLE_MANAGER_H

#include <QWidget>

#include <kdialog.h>
#include "kis_action_manager.h"

class ResourceBundle;
class QListWidget;
class QListWidgetItem;

namespace Ui
{
class WdgDlgBundleManager;
}

class DlgBundleManager : public KDialog
{
    Q_OBJECT
public:
    explicit DlgBundleManager(KisActionManager* actionMgr, QWidget *parent = 0);

private slots:

    void accept();
    void addSelected();
    void removeSelected();
    void itemSelected(QListWidgetItem *current, QListWidgetItem *previous);
    void itemSelected(QListWidgetItem *current);
    void editBundle();    
    void slotImportResource() ;
    void slotCreateBundle() ;
    void slotDeleteBackupFiles();
    void slotOpenResourceFolder();

private:

    QWidget *m_page;
    Ui::WdgDlgBundleManager *m_ui;

    void fillListWidget(QList<ResourceBundle*> bundles, QListWidget *w);

    QMap<QString, ResourceBundle*> m_blacklistedBundles;
    QMap<QString, ResourceBundle*> m_activeBundles;

    ResourceBundle *m_currentBundle;
    KisActionManager* m_actionManager;
};

#endif // DLG_BUNDLE_MANAGER_H
